<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam" :inline="true">
        <el-row :gutter="10">
          <el-col :span="9">
            <el-form-item label="预警时间">
              <el-date-picker v-model="querys[1].value" type="datetimerange" style="width: 100%"
                value-format="yyyy-MM-dd HH:mm:ss" range-separator="至" start-placeholder="开始日期" end-placeholder="结束日期">
              </el-date-picker>
            </el-form-item>
          </el-col>
          <el-col :span="6">
            <el-form-item label="预警设备标识">
              <el-input v-model="querys[2].value" placeholder="请输入预警设备标识" maxlength="32" clearable>
              </el-input>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="处理状态">
              <el-select v-model="querys[3].value" clearable style="width: 100%" placeholder="请选择处理状态">
                <el-option v-for="item in handleStatusList" :key="item.value" :label="item.name"
                  :value="item.value"></el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-form-item>
              <el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索</el-button>
              <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <div class="bbsl-table-content" ref="contentPanel">
      <div class="bbsl-btn-content" ref="btnPanel"></div>
      <el-table border size="mini" v-loading="loading" ref="multipleSelection" :data="tableData"
        :style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
        :header-cell-style="{ 'text-align': 'center' }" @row-dblclick="handleDbClick"
        @selection-change="handleSelectionChange">
        <el-table-column fixed type="index" width="55" label="序号"></el-table-column>
        <el-table-column min-width="100" fixed prop="deviceCode" label="预警设备标识" show-overflow-tooltip></el-table-column>
        <el-table-column fixed min-width="150" prop="warnName" label="预警名称" show-overflow-tooltip></el-table-column>
        <!-- <el-table-column
          min-width="90"
          
          prop="handleUser"
          label="创建人"
          show-overflow-tooltip
        ></el-table-column> -->
        <el-table-column min-width="120" prop="warnTime" label="预警时间" show-overflow-tooltip></el-table-column>
        <el-table-column min-width="100" prop="warnType" label="预警类型" show-overflow-tooltip>
        </el-table-column>
        <el-table-column min-width="60" prop="warnThreshold" label="预警阈值" show-overflow-tooltip>
        </el-table-column>
        <el-table-column min-width="120" prop="warnReason" label="预警缘由" show-overflow-tooltip></el-table-column>
        <!-- <el-table-column min-width="150" prop="handleTime" label="处理时间" show-overflow-tooltip>
        </el-table-column> -->
        <el-table-column min-width="90" prop="handleResult" label="处理结果" show-overflow-tooltip>
        </el-table-column>
        <el-table-column min-width="60" prop="handleCompletion" label="处理进度" show-overflow-tooltip>
        </el-table-column>
        <el-table-column min-width="60" label="处理状态" show-overflow-tooltip>
          <template slot-scope="scope">
            <div :style="scope.row.handleStatus == '待调度'
              ? { color: '#E6A23C' }
              : scope.row.handleStatus == '处置完成'
                ? { color: '#13ce66' }
                : scope.row.handleStatus == '待处理'
                  ? { color: '#ff4949' }
                  : scope.row.handleStatus == '正在处置'
                    ? { color: '#409EFF' }
                    : { color: '#409EFF' }
              ">
              {{ scope.row.handleStatus }}
            </div>
          </template>
        </el-table-column>
      </el-table>
      <el-pagination align="right" background class="bbsl-pagination" ref="paginationPanel"
        @size-change="handleSizeChange" @current-change="handleCurrentChange" :current-page="queryParam.pageBean.page"
        :page-sizes="[20, 30, 40, 50]" :page-size="queryParam.pageBean.pageSize"
        layout="total, sizes, prev, pager, next, jumper" :total="total"></el-pagination>
    </div>
    <warning ref="warningForm"></warning>
  </div>
</template>

<script>
import warning from '@/components/warningDialog/warning.vue'
import { TableMixin } from '@/mixins/tableMixin'
import dangerousDevice from '@/api/device/dangerousDevice.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'
export default {
  mixins: [TableMixin],
  props: {
    parameter: {
      type: Object,
      default: function () {
        return
      },
    },
  },
  components: {
    warning,
  },
  data() {
    return {
      querys: [
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'warn.DEVICE_CODE_',
          relation: 'AND',
          value: this.parameter.code,
        },
        {
          group: 'main',
          operation: 'BETWEEN',
          parentGroup: '',
          property: 'warnTime',
          relation: 'AND',
          value: '',
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'deviceCode',
          relation: 'AND',
          value: '',
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'handleStatus',
          relation: 'AND',
          value: '',
        },
      ],
      deviceTypeList: [], //设备预警类型字典
      handleStatusList: [], //处理状态字典
      warnTypeList: [], //预警类型字典
    }
  },
  created() {
    console.log(this.parameter)
    this.deviceTypeList = dictUtils.getDictItemsFromCache('gjsblx')
    this.handleStatusList = dictUtils.getDictItemsFromCache('clzt')
    this.warnTypeList = dictUtils.getDictItemsFromCache('gjlx')
  },
  methods: {
    handleUpdate(row) {
      console.log(row)
      this.$refs.warningForm.add(row)
    },
    // 重置
    clearQuerys() {
      this.querys[1].value = ''
      this.querys[2].value = ''
      this.querys[3].value = ''
    },
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      if (this.querys[2].value) {
        this.queryParam.querys.push(this.querys[2])
      }
      if (this.querys[3].value) {
        this.queryParam.querys.push(this.querys[3])
      }
      this.queryParam.sorter = [{
        direction: 'DESC',
        property: 'warnTime'
      }]
      dangerousDevice.loadInfo(this.queryParam, (res) => {
        // console.log(res, 'ppppppp')
        this.tableData = res.rows
        this.total = res.total
        this.$set(this.tableData)
        this.loading = false
        this.tableData.forEach((item) => {
          this.warnTypeList.forEach((val) => {
            if (item.warnType == val.value) {
              item['warnType'] = val.name
            }
          })
          this.handleStatusList.forEach((val) => {
            if (item.handleStatus == val.value) {
              item['handleStatus'] = val.name
            }
          })
        })
      })
    },
  },
}
</script>

<style lang="scss" scoped></style>
